@@ -291,6 +291,23 @@ class _Slice(CubePartition):
         """
         return Z_975 * self.column_std_err
 
+    @lazyproperty
+    def column_share_sum(self):
+        """2D optional np.float64 ndarray of column share sum value for each table cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+
+        Column share of sum is the sum of each subvar item divided by the TOTAL number
+        of column items.
+        """
+        try:
+            return self._assembler.column_share_sum
+        except ValueError:
+            raise ValueError(
+                "`.column_share_sum` is undefined for a cube-result without a sum "
+                "measure"
+            )
+
     @lazyproperty
     def column_std_dev(self):
         """standard deviation for column percentages
@@ -616,35 +633,58 @@ class _Slice(CubePartition):
         )
 
     @lazyproperty
-    def pairwise_significance_t_stats(self):
-        """3D ndarray of pairwise-significance t-stats matrices for each subvariable.
+    def pairwise_means_indices(self):
+        """Optional 2D ndarray of tuple column-idxs significance threshold for mean.
 
-        Each subvariable pairwise significance matrix is a 2D ndarray of the t-stats
-        for the selected subvariable index (the selected column).
-        """
+        Like::
 
-        # If overlaps are defined, calculate significance based on them
-        if (
-            self.dimension_types[-1] == DT.MR
-            and self._cube.overlaps is not None
-            and self._cube.valid_overlaps is not None
-        ):
-            return self._assembler.pairwise_significance_t_stats
-
-        # Wrap the legacy objects in a 3D ndarray, so that's interpretable by exporter
-        return np.array(
             [
-                PairwiseSignificance(self).values[column_idx].t_stats
-                for column_idx in range(len(self.column_labels))
+               [(1, 3, 4), (), (0,), (), ()],
+               [(2,), (1, 2), (), (), (0, 3)],
+               [(), (), (), (), ()],
             ]
-        )
+
+        Has the same shape as `.means`. Each int represents the offset of another
+        column in the same row with a confidence interval meeting the threshold defined
+        for this analysis.
+        """
+        try:
+            return self._assembler.pairwise_means_indices(
+                self._alpha, self._only_larger
+            )
+        except ValueError:
+            raise ValueError(
+                "`.pairwise_means_indices` is undefined for a cube-result "
+                "without a mean measure"
+            )
 
     @lazyproperty
-    def pairwise_significance_p_vals(self):
-        """3D ndarray of pairwise-significance p-vals matrices for each subvariable.
+    def pairwise_means_indices_alt(self):
+        """2D ndarray of tuple of column-idxs meeting alternate threshold for mean.
 
-        Each subvariable pairwise significance matrix is a 2D ndarray of the p-vals
-        for the selected subvariable index (the selected column).
+        This value is None if no alternate threshold has been defined.
+        """
+        if self._alpha_alt is None:
+            return None
+        try:
+            return self._assembler.pairwise_means_indices(
+                self._alpha_alt, self._only_larger
+            )
+        except ValueError:
+            raise ValueError(
+                "`.pairwise_means_indices_alt` is undefined for a cube-result "
+                "without a mean measure"
+            )
+
+    def pairwise_significance_p_vals(self, column_idx):
+        """2D ndarray of pairwise-significance p-vals matrices for column idx.
+
+        For cubes where the last dimension is categorical, column idxs represent
+        specific categories.
+
+        For cubes where the last dimension is a multiple response, each subvariable
+        pairwise significance matrix is a 2D ndarray of the p-vals for the selected
+        subvariable index (the selected column).
         """
 
         # If overlaps are defined, calculate significance based on them
@@ -653,15 +693,54 @@ class _Slice(CubePartition):
             and self._cube.overlaps is not None
             and self._cube.valid_overlaps is not None
         ):
-            return self._assembler.pairwise_significance_p_vals
+            return self._assembler.pairwise_significance_p_vals(column_idx)
 
-        # Wrap the legacy objects in a 3D ndarray, so that's interpretable by exporter
-        return np.array(
-            [
-                PairwiseSignificance(self).values[column_idx].p_vals
-                for column_idx in range(len(self.column_labels))
-            ]
-        )
+        # If overlaps are not defined, default to the old-way of calculation
+        return PairwiseSignificance(self).values[column_idx].p_vals
+
+    def pairwise_significance_t_stats(self, column_idx):
+        """return 2D ndarray of pairwise-significance t-stats matrices for subvariable.
+
+        For cubes where the last dimension is categorical, column idxs represent
+        specific categories.
+
+        For cubes where the last dimension is a multiple response, each subvariable
+        pairwise significance matrix is a 2D ndarray of the t-stats for the selected
+        subvariable index (the selected column).
+        """
+
+        # If overlaps are defined, calculate significance based on them
+        if (
+            self.dimension_types[-1] == DT.MR
+            and self._cube.overlaps is not None
+            and self._cube.valid_overlaps is not None
+        ):
+            return self._assembler.pairwise_significance_t_stats(column_idx)
+
+        # If overlaps are not defined, default to the old-way of calculation
+        return PairwiseSignificance(self).values[column_idx].t_stats
+
+    def pairwise_significance_means_p_vals(self, column_idx):
+        """Optional 2D ndarray of means significance p-vals matrices for column idx."""
+        # Significance of means difference is available only is cube contains means.
+        try:
+            return self._assembler.pairwise_significance_means_p_vals(column_idx)
+        except ValueError:
+            raise ValueError(
+                "`.pairwise_significance_means_p_vals` is undefined for a cube-result "
+                "without a mean measure"
+            )
+
+    def pairwise_significance_means_t_stats(self, column_idx):
+        """Optional 2D ndarray of means significance t-stats matrices for column idx."""
+        # Significance of means difference is available only is cube contains means.
+        try:
+            return self._assembler.pairwise_significance_means_t_stats(column_idx)
+        except ValueError:
+            raise ValueError(
+                "`.pairwise_significance_means_t_stats` is undefined for a cube-result "
+                "without a mean measure"
+            )
 
     @lazyproperty
     def pairwise_significance_tests(self):
@@ -747,6 +826,22 @@ class _Slice(CubePartition):
         """
         return Z_975 * self.row_std_err
 
+    @lazyproperty
+    def row_share_sum(self):
+        """2D optional np.float64 ndarray of row share sum value for each table cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+
+        Row share of sum is the sum of each subvar item divided by the TOTAL number of
+        row items.
+        """
+        try:
+            return self._assembler.row_share_sum
+        except ValueError:
+            raise ValueError(
+                "`.row_share_sum` is undefined for a cube-result without a sum measure"
+            )
+
     @lazyproperty
     def row_std_dev(self):
         """2D np.float64 ndarray of standard deviation for row percentages."""
@@ -969,22 +1064,6 @@ class _Slice(CubePartition):
     def shape(self):
         return self.counts.shape
 
-    @lazyproperty
-    def share_sum(self):
-        """2D optional np.float64 ndarray of share of sum value for each table cell.
-
-        Raises `ValueError` if the cube-result does not include a sum cube-measure.
-
-        Share of sum is the sum of each subvar item divided by the TOTAL number of
-        items.
-        """
-        try:
-            return self._assembler.share_sum
-        except ValueError:
-            raise ValueError(
-                "`.share_sum` is undefined for a cube-result without a sum measure"
-            )
-
     @lazyproperty
     def smoothed_dimension_dict(self):
         """dict, smoothed column dimension definition"""
@@ -1145,6 +1224,22 @@ class _Slice(CubePartition):
         """2D np.float64 ndarray of table-proportion denominator for each cell."""
         return self._assembler.table_weighted_bases
 
+    @lazyproperty
+    def total_share_sum(self):
+        """2D optional np.float64 ndarray of total share sum value for each table cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+
+        Total share of sum is the sum of each subvar item divided by the TOTAL of items.
+        """
+        try:
+            return self._assembler.total_share_sum
+        except ValueError:
+            raise ValueError(
+                "`.total_share_sum` is undefined for a cube-result without a sum "
+                "measure"
+            )
+
     @lazyproperty
     def unweighted_counts(self):
         """2D np.float64 ndarray of unweighted count for each slice matrix cell."""
