@@ -326,7 +326,9 @@ class Dimension(object):
         a separate `.display_order` attribute on _AllElements.
         """
         return _AllElements(
-            self._dimension_dict["type"], self._dimension_transforms_dict
+            self._dimension_dict["type"],
+            self._dimension_transforms_dict,
+            self._dimension_type,
         )
 
     def apply_transforms(self, dimension_transforms):
@@ -568,9 +570,10 @@ class _AllElements(_BaseElements):
     Each element is either a category or a subvariable.
     """
 
-    def __init__(self, type_dict, dimension_transforms_dict):
+    def __init__(self, type_dict, dimension_transforms_dict, dimension_type):
         self._type_dict = type_dict
         self._dimension_transforms_dict = dimension_transforms_dict
+        self._dimension_type = dimension_type
 
     @lazyproperty
     def valid_elements(self):
@@ -586,6 +589,22 @@ class _AllElements(_BaseElements):
             else self._type_dict["elements"]
         )
 
+    def _element_id_from_dict(self, element_dict):
+        """Returns the element identifier given its dict."""
+        key = self._elements_transforms.get("key")
+        default_id = element_dict["id"]
+        if self._dimension_type in DT.ARRAY_TYPES:
+            element_value = element_dict.get("value", {})
+            if key == "alias":
+                # --- In case of specified key alias, returns the subvariable alias.
+                return element_value.get("references", {}).get("alias") or default_id
+            elif key == "subvar_id":
+                return element_value.get("id")
+            # --- Returns the subvariable id.
+            return element_value.get("id") or default_id
+        # --- Fallback case is the positional idx.
+        return default_id
+
     @lazyproperty
     def _elements(self):
         """tuple storing actual sequence of element objects."""
@@ -602,6 +621,11 @@ class _AllElements(_BaseElements):
             ) in self._iter_element_makings()
         )
 
+    @lazyproperty
+    def _elements_transforms(self):
+        """Element transform dict expressed in the dimension transforms expression."""
+        return self._dimension_transforms_dict.get("elements", {})
+
     def _iter_element_makings(self):
         """Generate tuple of values needed to construct each element object.
 
@@ -609,16 +633,18 @@ class _AllElements(_BaseElements):
         element in this dimension, in the order they appear in the cube-result. All
         elements are included (including missing).
         """
-        element_dicts = self._element_dicts
-        elements_transforms = self._dimension_transforms_dict.get("elements", {})
-        for idx, element_dict in enumerate(element_dicts):
-            element_id = element_dict["id"]
+        elements_transforms = self._elements_transforms
+        for idx, element_dict in enumerate(self._element_dicts):
+            element_id = self._element_id_from_dict(element_dict)
             # TODO: Each element transforms dict is keyed by the str() version of it int
             # value as a consequence of JSON serialization (which does not allow
             # non-string keys). Hence the str(element_id) here.
-            element_transforms_dict = elements_transforms.get(
-                element_id, elements_transforms.get(str(element_id), {})
-            )
+            element_transforms_dict = elements_transforms.get(element_id, {})
+            if not element_transforms_dict:
+                element_transforms_dict = elements_transforms.get(
+                    element_dict["id"],
+                    elements_transforms.get(str(element_dict["id"]), {}),
+                )
             yield idx, element_dict, element_transforms_dict
 
 
