@@ -86,6 +86,14 @@ class Assembler(object):
         """
         return self._assemble_matrix(self._measures.column_proportions.blocks)
 
+    @lazyproperty
+    def column_share_sum(self):
+        """2D optional np.float64 ndarray of column share of sum for each cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+        """
+        return self._assemble_matrix(self._measures.column_share_sum.blocks)
+
     @lazyproperty
     def column_unweighted_bases(self):
         """2D np.float64 ndarray of unweighted col-proportions denominator per cell."""
@@ -104,7 +112,7 @@ class Assembler(object):
         rows_dim_type = self._rows_dimension.dimension_type
         if rows_dim_type in (DT.MR_SUBVAR, DT.NUM_ARRAY):
             return self._assemble_matrix(
-                SumSubtotals.blocks(columns_base, self._dimensions)
+                SumSubtotals.blocks(columns_base, self._dimensions, diff_cols_nan=True)
             )
 
         # --- otherwise columns-base is a vector ---
@@ -112,6 +120,7 @@ class Assembler(object):
             columns_base,
             self._column_subtotals,
             self._column_order,
+            diffs_nan=True,
         )
 
     @lazyproperty
@@ -136,7 +145,8 @@ class Assembler(object):
         if self._rows_dimension.dimension_type == DT.MR_SUBVAR:
             return self._assemble_matrix(
                 SumSubtotals.blocks(
-                    self._cube_result_matrix.columns_margin, self._dimensions
+                    self._cube_result_matrix.columns_margin,
+                    self._dimensions,
                 )
             )
 
@@ -167,36 +177,51 @@ class Assembler(object):
         """
         return self._assemble_matrix(self._measures.means.blocks)
 
-    @lazyproperty
-    def pairwise_significance_p_vals(self):
-        """3D optional np.float64 ndarray of overlaps-p_vals matrices for each subvar.
+    def pairwise_means_indices(self, alpha, only_larger):
+        """2D optional ndarray of tuple of int column-idxs means pairwise-t threshold.
 
-        Raises `ValueError if the cube-result does not include `overlaps`
-        and `valid_overlaps` cube-measures.
+        Raises `ValueError if the cube-result does not include `means` cube-measures.
         """
-        return np.array(
-            [
-                self._assemble_matrix(
-                    self._measures.pairwise_p_vals_for_subvar(subvar_idx).blocks
-                )
-                for subvar_idx in range(len(self.column_labels))
-            ]
+        return self._assemble_matrix(
+            self._measures.pairwise_means_indices(alpha, only_larger).blocks
         )
 
-    @lazyproperty
-    def pairwise_significance_t_stats(self):
-        """3D optional np.float64 ndarray of overlaps-t_stats matrices for each subvar.
+    def pairwise_significance_p_vals(self, subvar_idx):
+        """2D optional np.float64 ndarray of overlaps-p_vals matrices for subvar idx.
 
         Raises `ValueError if the cube-result does not include `overlaps`
         and `valid_overlaps` cube-measures.
         """
-        return np.array(
-            [
-                self._assemble_matrix(
-                    self._measures.pairwise_t_stats_for_subvar(subvar_idx).blocks
-                )
-                for subvar_idx in range(len(self.column_labels))
-            ]
+        return self._assemble_matrix(
+            self._measures.pairwise_p_vals_for_subvar(subvar_idx).blocks
+        )
+
+    def pairwise_significance_t_stats(self, subvar_idx):
+        """2D optional np.float64 ndarray of overlaps-t_stats matrices for subvar idx.
+
+        Raises `ValueError if the cube-result does not include `overlaps`
+        and `valid_overlaps` cube-measures.
+        """
+        return self._assemble_matrix(
+            self._measures.pairwise_t_stats_for_subvar(subvar_idx).blocks
+        )
+
+    def pairwise_significance_means_p_vals(self, column_idx):
+        """2D optional np.float64 ndarray of mean difference p_vals for column idx.
+
+        Raises `ValueError if the cube-result does not include `mean` cube-measures.
+        """
+        return self._assemble_matrix(
+            self._measures.pairwise_significance_means_p_vals(column_idx).blocks
+        )
+
+    def pairwise_significance_means_t_stats(self, column_idx):
+        """2D optional np.float64 ndarray of mean difference t_stats for column idx.
+
+        Raises `ValueError if the cube-result does not include `mean` cube-measures.
+        """
+        return self._assemble_matrix(
+            self._measures.pairwise_significance_means_t_stats(column_idx).blocks
         )
 
     @lazyproperty
@@ -224,6 +249,14 @@ class Assembler(object):
         """
         return self._assemble_matrix(self._measures.row_proportions.blocks)
 
+    @lazyproperty
+    def row_share_sum(self):
+        """2D optional np.float64 ndarray of row share of sum for each cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+        """
+        return self._assemble_matrix(self._measures.row_share_sum.blocks)
+
     @lazyproperty
     def row_unweighted_bases(self):
         """2D np.float64 ndarray of unweighted row-proportions denominator per cell."""
@@ -241,13 +274,18 @@ class Assembler(object):
         if self._columns_dimension.dimension_type == DT.MR_SUBVAR:
             return self._assemble_matrix(
                 SumSubtotals.blocks(
-                    self._cube_result_matrix.rows_base, self._dimensions
+                    self._cube_result_matrix.rows_base,
+                    self._dimensions,
+                    diff_rows_nan=True,
                 )
             )
 
         # --- otherwise rows-base is a vector ---
         return self._assemble_vector(
-            self._cube_result_matrix.rows_base, self._row_subtotals, self._row_order
+            self._cube_result_matrix.rows_base,
+            self._row_subtotals,
+            self._row_order,
+            diffs_nan=True,
         )
 
     @lazyproperty
@@ -293,14 +331,6 @@ class Assembler(object):
             self._cube_result_matrix.rows_margin, self._row_subtotals, self._row_order
         )
 
-    @lazyproperty
-    def share_sum(self):
-        """2D optional np.float64 ndarray of share of sum for each cell.
-
-        Raises `ValueError` if the cube-result does not include a sum cube-measure.
-        """
-        return self._assemble_matrix(self._measures.share_sum.blocks)
-
     @lazyproperty
     def sums(self):
         """2D optional np.float64 ndarray of sum for each cell.
@@ -460,6 +490,14 @@ class Assembler(object):
         """2D np.float64 ndarray of weighted table-proportion denominator per cell."""
         return self._assemble_matrix(self._measures.table_weighted_bases.blocks)
 
+    @lazyproperty
+    def total_share_sum(self):
+        """2D optional np.float64 ndarray of total share of sum for each cell.
+
+        Raises `ValueError` if the cube-result does not include a sum cube-measure.
+        """
+        return self._assemble_matrix(self._measures.total_share_sum.blocks)
+
     @lazyproperty
     def unweighted_counts(self):
         """2D np.float64 ndarray of unweighted-count for each cell."""
@@ -511,7 +549,7 @@ class Assembler(object):
         # --- desired output.
         return np.block(blocks)[np.ix_(self._row_order, self._column_order)]
 
-    def _assemble_vector(self, base_vector, subtotals, order):
+    def _assemble_vector(self, base_vector, subtotals, order, diffs_nan=False):
         """Return 1D ndarray of `base_vector` with inserted `subtotals`, in `order`.
 
         Each subtotal value is the result of applying np.sum to the addends and
@@ -520,12 +558,14 @@ class Assembler(object):
         array is arranged by `order`, including possibly removing hidden or pruned
         values.
         """
-        # TODO: This works for "sum" and "diff" subtotals, which is all that it needs
-        # so far, but a fuller solution will probably get the subtotal values from a
-        # _BaseSubtotals subclass.
+        # TODO: This works for "sum" and "diff" subtotals, because either we set to
+        # nan or add & subtract, but a fuller solution will probably get the subtotal
+        # values from a _BaseSubtotals subclass.
         vector_subtotals = np.array(
             [
-                np.sum(base_vector[subtotal.addend_idxs])
+                np.nan
+                if diffs_nan and len(subtotal.subtrahend_idxs) > 0
+                else np.sum(base_vector[subtotal.addend_idxs])
                 - np.sum(base_vector[subtotal.subtrahend_idxs])
                 for subtotal in subtotals
             ]
