@@ -596,7 +596,10 @@ class DescribeAssembler(object):
             [341, 175, 166, 234, 234],
         ]
 
-    def it_computes_unweighted_counts_for_ca_subvar_x_ca_cat_hiddens(self):
+    @pytest.mark.parametrize(
+        "hidden_rows", ({"5": {"hide": True}}, {"00004": {"hide": True}})
+    )
+    def it_computes_unweighted_counts_for_ca_subvar_x_ca_cat_hiddens(self, hidden_rows):
         """Assembler hides, prunes, and places in payload order.
 
         This fixture has no insertions, and exercises the "no-insertions" case which
@@ -606,7 +609,7 @@ class DescribeAssembler(object):
             Cube(CR.CA_SUBVAR_X_CA_CAT_EMPTIES),
             slice_idx=0,
             transforms={
-                "rows_dimension": {"elements": {"5": {"hide": True}}, "prune": True},
+                "rows_dimension": {"elements": hidden_rows, "prune": True},
                 "columns_dimension": {
                     "elements": {"99": {"hide": True}},
                     "prune": True,
