@@ -10,7 +10,7 @@ import pytest
 from cr.cube.cube import Cube
 from cr.cube.cubepart import _Slice
 
-from ..fixtures import CR, OL, SM
+from ..fixtures import CR, OL, SM, NA
 from ..util import load_python_expression
 
 
@@ -145,11 +145,11 @@ class TestStandardizedResiduals(TestCase):
         )
         # check new api also
         np.testing.assert_array_almost_equal(
-            slice_.pairwise_significance_t_stats[1],
+            slice_.pairwise_significance_t_stats(1),
             load_python_expression("ca-subvar-hs-x-cat-hs-pw-tstats"),
         )
         np.testing.assert_array_almost_equal(
-            slice_.pairwise_significance_p_vals[1],
+            slice_.pairwise_significance_p_vals(1),
             load_python_expression("ca-subvar-hs-x-cat-hs-pw-pvals"),
         )
 
@@ -190,11 +190,11 @@ class TestStandardizedResiduals(TestCase):
         )
         # test new api also
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[2],
+            slice_.pairwise_significance_t_stats(2),
             load_python_expression("cat-x-cat-pw-tstats"),
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[2],
+            slice_.pairwise_significance_p_vals(2),
             load_python_expression("cat-x-cat-pw-pvals"),
         )
 
@@ -211,11 +211,11 @@ class TestStandardizedResiduals(TestCase):
         )
         # test new api also
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[0],
+            slice_.pairwise_significance_t_stats(0),
             load_python_expression("cat-x-cat-hs-pw-tstats"),
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[0],
+            slice_.pairwise_significance_p_vals(0),
             load_python_expression("cat-x-cat-hs-pw-pvals"),
         )
 
@@ -330,11 +330,11 @@ class TestStandardizedResiduals(TestCase):
         )
         # test new api also
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[0],
+            slice_.pairwise_significance_t_stats(0),
             load_python_expression("cat-x-cat-wgtd-pw-tstats"),
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[0],
+            slice_.pairwise_significance_p_vals(0),
             load_python_expression("cat-x-cat-wgtd-pw-pvals"),
         )
 
@@ -362,11 +362,11 @@ class TestStandardizedResiduals(TestCase):
         )
         # test new api also
         np.testing.assert_array_almost_equal(
-            slice_.pairwise_significance_t_stats[1],
+            slice_.pairwise_significance_t_stats(1),
             load_python_expression("mr-x-mr-pw-tstats"),
         )
         np.testing.assert_array_almost_equal(
-            slice_.pairwise_significance_p_vals[1],
+            slice_.pairwise_significance_p_vals(1),
             load_python_expression("mr-x-mr-pw-pvals"),
         )
 
@@ -376,14 +376,14 @@ class TestOverlapsPairwiseSignificance(TestCase):
         slice_ = Cube(OL.CAT_X_MR_SUB_X_MR_SEL).partitions[0]
 
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[0],
+            slice_.pairwise_significance_t_stats(0),
             [
                 [0.0, -1.22474487, -2.44948974],
                 [0.0, 1.41421356, 1.41421356],
             ],
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[0],
+            slice_.pairwise_significance_p_vals(0),
             [
                 [0.0, 0.43590578, 0.24675171],
                 [0.0, np.nan, np.nan],
@@ -394,14 +394,14 @@ class TestOverlapsPairwiseSignificance(TestCase):
         slice_ = Cube(OL.CAT_X_MR_SUB_X_MR_SEL).partitions[0]
 
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[1],
+            slice_.pairwise_significance_t_stats(1),
             [
                 [1.22474487, 0.0, -1.22474487],
                 [-1.41421356, 0.0, np.nan],
             ],
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[1],
+            slice_.pairwise_significance_p_vals(1),
             [
                 [0.43590578, 0.0, 0.43590578],
                 [np.nan, 0.0, np.nan],
@@ -412,14 +412,14 @@ class TestOverlapsPairwiseSignificance(TestCase):
         slice_ = Cube(OL.CAT_X_MR_SUB_X_MR_SEL).partitions[0]
 
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[2],
+            slice_.pairwise_significance_t_stats(2),
             [
                 [2.44948974, 1.22474487, 0.0],
                 [-1.41421356, np.nan, 0.0],
             ],
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[2],
+            slice_.pairwise_significance_p_vals(2),
             [
                 [0.24675171, 0.43590578, 0.0],
                 [np.nan, np.nan, 0.0],
@@ -430,7 +430,7 @@ class TestOverlapsPairwiseSignificance(TestCase):
         slice_ = Cube(OL.CAT_X_MR_REALISTIC_EXAMPLE).partitions[0]
 
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_t_stats[4],
+            slice_.pairwise_significance_t_stats(4),
             [
                 [
                     -3.9146295258075634,
@@ -451,7 +451,7 @@ class TestOverlapsPairwiseSignificance(TestCase):
             ],
         )
         np.testing.assert_almost_equal(
-            slice_.pairwise_significance_p_vals[4],
+            slice_.pairwise_significance_p_vals(4),
             [
                 [
                     0.0001337008782529292,
@@ -471,3 +471,161 @@ class TestOverlapsPairwiseSignificance(TestCase):
                 ],
             ],
         )
+
+    def test_pairwise_significance_mr_x_mr(self):
+        slice_ = Cube(OL.MR_X_MR).partitions[0]
+
+        np.testing.assert_almost_equal(
+            slice_.pairwise_significance_t_stats(1),
+            [
+                [-1.11803399, 0.0, 1.82574186],
+                [1.47709789, 0.0, 3.46410162],
+                [np.nan, 0.0, np.nan],
+            ],
+        )
+        np.testing.assert_almost_equal(
+            slice_.pairwise_significance_p_vals(1),
+            [
+                [0.34501476, 0.0, 0.1653704],
+                [0.21370636, 0.0, 0.02572142],
+                [np.nan, 0.0, np.nan],
+            ],
+        )
+
+
+class TestMeanDifferenceSignificance(object):
+    def test_mean_diff_significance_for_numeric_array_grouped_by_cat(self):
+        slice_ = Cube(NA.NUM_ARR_MULTI_NUMERIC_MEASURES_GROUPED_BY_CAT).partitions[0]
+
+        assert slice_.pairwise_significance_means_t_stats(0) == pytest.approx(
+            np.array(
+                [
+                    [0.0, 0.7482866, 4.61524529, 5.29463547],
+                    [0.0, 4.64371041, 7.14738681, 3.67511747],
+                    [0.0, -3.13387218, -6.35310465, -2.3932706],
+                ]
+            )
+        )
+        assert slice_.pairwise_significance_means_p_vals(0) == pytest.approx(
+            np.array(
+                [
+                    [1.00000000e00, 4.60526868e-01, 5.38716457e-05, 7.11866628e-06],
+                    [1.00000000e00, 7.34317022e-05, 2.90876736e-08, 8.12768987e-04],
+                    [1.00000000e00, 4.02303806e-03, 3.00760739e-07, 2.23647892e-02],
+                ]
+            )
+        )
+
+    def test_mean_diff_significance_for_numeric_array_x_mr(self):
+        slice_ = Cube(NA.NUM_ARR_MULTI_NUMERIC_MEASURES_X_MR).partitions[0]
+
+        assert slice_.pairwise_significance_means_t_stats(0) == pytest.approx(
+            np.array(
+                [
+                    [0.0, -1.3056921, 1.1842639],
+                    [0.0, -1.7117695, 1.6297401],
+                    [np.nan, np.nan, np.nan],
+                    [np.nan, 5.8872721, 4.4442801],
+                ]
+            ),
+            nan_ok=True,
+        )
+        assert slice_.pairwise_significance_means_p_vals(0) == pytest.approx(
+            np.array(
+                [
+                    [1.00000000e00, 1.96331347e-01, 2.40688158e-01],
+                    [1.00000000e00, 9.17815019e-02, 1.08068956e-01],
+                    [np.nan, np.nan, np.nan],
+                    [np.nan, 1.57810759e-07, 3.57756031e-05],
+                ]
+            ),
+            nan_ok=True,
+        )
+
+    def test_mean_diff_significance_indices_for_numeric_array_grouped_by_cat(self):
+        transforms = {"pairwise_indices": {"alpha": [0.05, 0.08]}}
+        slice_ = Cube(
+            NA.NUM_ARR_MULTI_NUMERIC_MEASURES_GROUPED_BY_CAT, transforms=transforms
+        ).partitions[0]
+
+        assert slice_.pairwise_means_indices.tolist() == [
+            [(), (), (0, 1), (0, 1)],
+            [(), (0,), (0,), (0,)],
+            [(1, 2, 3), (2,), (), (2,)],
+        ]
+        assert slice_.pairwise_means_indices_alt.tolist() == [
+            [(), (), (0, 1), (0, 1)],
+            [(), (0,), (0, 3), (0,)],
+            [(1, 2, 3), (2,), (), (2,)],
+        ]
+
+    def test_mean_diff_significance_is_not_available(self):
+        transforms = {"pairwise_indices": {"alpha": [0.05, 0.08]}}
+        slice_ = Cube(CR.CAT_X_CAT, transforms=transforms).partitions[0]
+
+        with pytest.raises(ValueError) as e:
+            slice_.pairwise_means_indices
+        assert (
+            str(e.value) == "`.pairwise_means_indices` is undefined for a cube-result"
+            " without a mean measure"
+        )
+        with pytest.raises(ValueError) as e:
+            slice_.pairwise_means_indices_alt
+        assert (
+            str(e.value)
+            == "`.pairwise_means_indices_alt` is undefined for a cube-result"
+            " without a mean measure"
+        )
+        with pytest.raises(ValueError) as e:
+            slice_.pairwise_significance_means_p_vals(0)
+        assert (
+            str(e.value)
+            == "`.pairwise_significance_means_p_vals` is undefined for a cube-result"
+            " without a mean measure"
+        )
+        with pytest.raises(ValueError) as e:
+            slice_.pairwise_significance_means_t_stats(0)
+        assert (
+            str(e.value)
+            == "`.pairwise_significance_means_t_stats` is undefined for a cube-result"
+            " without a mean measure"
+        )
+
+    def test_mean_diff_significance_for_cat_x_cat(self):
+        slice_ = Cube(CR.MEAN_CAT_X_CAT).partitions[0]
+
+        assert slice_.pairwise_significance_means_t_stats(1) == pytest.approx(
+            np.array(
+                [
+                    [np.nan, np.nan, np.nan, np.nan],
+                    [-14.1421356, 0.0, -3.1066887, np.nan],
+                    [-1.75662013, 0.0, np.nan, np.nan],
+                ]
+            ),
+            nan_ok=True,
+        )
+        assert slice_.pairwise_significance_means_p_vals(1) == pytest.approx(
+            np.array(
+                [
+                    [np.nan, np.nan, np.nan, np.nan],
+                    [8.21565038e-15, 1.00000000e00, 4.80968355e-03, np.nan],
+                    [8.91869315e-02, 1.00000000e00, np.nan, np.nan],
+                ]
+            ),
+            nan_ok=True,
+        )
+
+    def test_mean_diff_significance_indices_for_cat_x_cat(self):
+        transforms = {"pairwise_indices": {"alpha": [0.05, 0.01]}}
+        slice_ = Cube(CR.MEAN_CAT_X_CAT, transforms=transforms).partitions[0]
+
+        assert slice_.pairwise_means_indices.tolist() == [
+            [(), (), (), ()],
+            [(), (0, 2), (0,), ()],
+            [(), (), (), ()],
+        ]
+        assert slice_.pairwise_means_indices_alt.tolist() == [
+            [(3,), (), (3,), ()],
+            [(), (0, 2), (0,), ()],
+            [(), (), (), ()],
+        ]
