@@ -10,7 +10,6 @@ from cr.cube.matrix.cubemeasure import BaseCubeResultMatrix
 from cr.cube.matrix.subtotals import (
     _BaseSubtotals,
     NanSubtotals,
-    SumDiffSubtotals,
     SumSubtotals,
     TableStdErrSubtotals,
     ZscoreSubtotals,
@@ -217,7 +216,7 @@ class DescribeSumSubtotals(object):
 
         intersections = SumSubtotals.intersections(base_values, dimensions_)
 
-        _init_.assert_called_once_with(ANY, [[1, 5], [8, 0]], dimensions_)
+        _init_.assert_called_once_with(ANY, [[1, 5], [8, 0]], dimensions_, False, False)
         assert intersections.tolist() == [[1, 2], [3, 4]]
 
     def it_provides_a_subtotal_columns_interface_method(
@@ -233,7 +232,7 @@ class DescribeSumSubtotals(object):
 
         subtotal_columns = SumSubtotals.subtotal_columns(base_values, dimensions_)
 
-        _init_.assert_called_once_with(ANY, [[0, 4], [7, 9]], dimensions_)
+        _init_.assert_called_once_with(ANY, [[0, 4], [7, 9]], dimensions_, False, False)
         assert subtotal_columns.tolist() == [[1, 2], [3, 4]]
 
     def it_provides_a_subtotal_rows_interface_method(
@@ -249,156 +248,6 @@ class DescribeSumSubtotals(object):
 
         subtotal_rows = SumSubtotals.subtotal_rows(base_values, dimensions_)
 
-        _init_.assert_called_once_with(ANY, [[4, 1], [3, 5]], dimensions_)
-        assert subtotal_rows.tolist() == [[4, 3], [2, 1]]
-
-    @pytest.mark.parametrize(
-        (
-            "row_add_idxs",
-            "row_sub_idxs",
-            "col_add_idxs",
-            "col_sub_idxs",
-            "expected_value",
-        ),
-        (
-            ([1, 2], [], [0, 1], [], 26),
-            ([0, 1], [], [0, 1], [], 10),
-            ([1, 2], [], [2, 3], [], 34),
-            ([1, 2], [0], [0, 1], [], 27),
-            ([1, 2], [], [0, 1], [2, 3], 60),
-            ([0, 1], [2], [2, 3], [0, 1], 66),
-            ([], [1, 2], [], [0, 1], 26),
-        ),
-    )
-    def it_can_compute_a_subtotal_intersection_value(
-        self,
-        request,
-        row_add_idxs,
-        row_sub_idxs,
-        col_add_idxs,
-        col_sub_idxs,
-        expected_value,
-    ):
-        col_subtotal_ = instance_mock(
-            request,
-            _Subtotal,
-            addend_idxs=col_add_idxs,
-            subtrahend_idxs=col_sub_idxs,
-        )
-        row_subtotal_ = instance_mock(
-            request,
-            _Subtotal,
-            addend_idxs=row_add_idxs,
-            subtrahend_idxs=row_sub_idxs,
-        )
-        base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumSubtotals(base_values, None)
-
-        assert subtotals._intersection(row_subtotal_, col_subtotal_) == expected_value
-
-    @pytest.mark.parametrize(
-        ("addend_idxs", "subtrahend_idxs", "expected_value"),
-        (
-            ([1, 2], [], [3, 11, 19]),
-            ([1, 3], [], [4, 12, 20]),
-            ([0, 3], [], [3, 11, 19]),
-            ([], [1, 2], [3, 11, 19]),
-            ([1], [3], [4, 12, 20]),
-        ),
-    )
-    def it_can_compute_a_subtotal_column_to_help(
-        self, subtotal_, addend_idxs, subtrahend_idxs, expected_value
-    ):
-        subtotal_.addend_idxs = addend_idxs
-        subtotal_.subtrahend_idxs = subtrahend_idxs
-        base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumSubtotals(base_values, None)
-
-        assert subtotals._subtotal_column(subtotal_).tolist() == expected_value
-
-    @pytest.mark.parametrize(
-        ("addend_idxs", "subtrahend_idxs", "expected_value"),
-        (
-            ([1, 2], [], [12, 14, 16, 18]),
-            ([0, 1], [], [4, 6, 8, 10]),
-            ([0, 2], [], [8, 10, 12, 14]),
-            ([], [1, 2], [12, 14, 16, 18]),
-            ([0], [2], [8, 10, 12, 14]),
-        ),
-    )
-    def it_can_compute_a_subtotal_row_to_help(
-        self, subtotal_, addend_idxs, subtrahend_idxs, expected_value
-    ):
-        subtotal_.addend_idxs = addend_idxs
-        subtotal_.subtrahend_idxs = subtrahend_idxs
-        base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumSubtotals(base_values, None)
-
-        assert subtotals._subtotal_row(subtotal_).tolist() == expected_value
-
-    # --- fixture components -----------------------------------------
-
-    @pytest.fixture
-    def dimensions_(self, request):
-        return (instance_mock(request, Dimension), instance_mock(request, Dimension))
-
-    @pytest.fixture
-    def _init_(self, request):
-        return initializer_mock(request, SumSubtotals)
-
-    @pytest.fixture
-    def subtotal_(self, request):
-        return instance_mock(request, _Subtotal)
-
-
-class DescribeSumDiffSubtotals(object):
-    """Unit test suite for `cr.cube.matrix.SumDiffSubtotals` object."""
-
-    def it_provides_an_intersections_interface_method(
-        self, request, dimensions_, _init_
-    ):
-        base_values = [[1, 5], [8, 0]]
-        property_mock(
-            request,
-            SumDiffSubtotals,
-            "_intersections",
-            return_value=np.array([[1, 2], [3, 4]]),
-        )
-
-        intersections = SumDiffSubtotals.intersections(base_values, dimensions_)
-
-        _init_.assert_called_once_with(ANY, [[1, 5], [8, 0]], dimensions_, False, False)
-        assert intersections.tolist() == [[1, 2], [3, 4]]
-
-    def it_provides_a_subtotal_columns_interface_method(
-        self, request, dimensions_, _init_
-    ):
-        base_values = [[0, 4], [7, 9]]
-        property_mock(
-            request,
-            SumDiffSubtotals,
-            "_subtotal_columns",
-            return_value=np.array([[1, 2], [3, 4]]),
-        )
-
-        subtotal_columns = SumDiffSubtotals.subtotal_columns(base_values, dimensions_)
-
-        _init_.assert_called_once_with(ANY, [[0, 4], [7, 9]], dimensions_, False, False)
-        assert subtotal_columns.tolist() == [[1, 2], [3, 4]]
-
-    def it_provides_a_subtotal_rows_interface_method(
-        self, request, dimensions_, _init_
-    ):
-        base_values = [[4, 1], [3, 5]]
-        property_mock(
-            request,
-            SumDiffSubtotals,
-            "_subtotal_rows",
-            return_value=np.array([[4, 3], [2, 1]]),
-        )
-
-        subtotal_rows = SumDiffSubtotals.subtotal_rows(base_values, dimensions_)
-
         _init_.assert_called_once_with(ANY, [[4, 1], [3, 5]], dimensions_, False, False)
         assert subtotal_rows.tolist() == [[4, 3], [2, 1]]
 
@@ -448,7 +297,7 @@ class DescribeSumDiffSubtotals(object):
             subtrahend_idxs=row_sub_idxs,
         )
         base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumDiffSubtotals(base_values, None, diff_cols_nan, diff_rows_nan)
+        subtotals = SumSubtotals(base_values, None, diff_cols_nan, diff_rows_nan)
 
         np.testing.assert_equal(
             subtotals._intersection(row_subtotal_, col_subtotal_), expected_value
@@ -471,7 +320,7 @@ class DescribeSumDiffSubtotals(object):
         subtotal_.addend_idxs = addend_idxs
         subtotal_.subtrahend_idxs = subtrahend_idxs
         base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumDiffSubtotals(base_values, None, diff_cols_nan=diff_cols_nan)
+        subtotals = SumSubtotals(base_values, None, diff_cols_nan=diff_cols_nan)
 
         assert subtotals._subtotal_column(subtotal_).tolist() == pytest.approx(
             expected_value, nan_ok=True
@@ -494,7 +343,7 @@ class DescribeSumDiffSubtotals(object):
         subtotal_.addend_idxs = addend_idxs
         subtotal_.subtrahend_idxs = subtrahend_idxs
         base_values = np.arange(12).reshape(3, 4)
-        subtotals = SumDiffSubtotals(base_values, None, diff_rows_nan=diff_rows_nan)
+        subtotals = SumSubtotals(base_values, None, diff_rows_nan=diff_rows_nan)
 
         assert subtotals._subtotal_row(subtotal_).tolist() == pytest.approx(
             expected_value, nan_ok=True
@@ -508,7 +357,7 @@ class DescribeSumDiffSubtotals(object):
 
     @pytest.fixture
     def _init_(self, request):
-        return initializer_mock(request, SumDiffSubtotals)
+        return initializer_mock(request, SumSubtotals)
 
     @pytest.fixture
     def subtotal_(self, request):
