@@ -731,7 +731,7 @@ class Describe_AllElements(object):
         dimension_transforms_dict = {"dimension": "transforms"}
         _elements_prop_.return_value = elements_
         _ValidElements_.return_value = valid_elements_
-        all_elements = _AllElements(None, dimension_transforms_dict)
+        all_elements = _AllElements(None, dimension_transforms_dict, None)
 
         valid_elements = all_elements.valid_elements
 
@@ -762,7 +762,7 @@ class Describe_AllElements(object):
             for idx in range(3)
         )
         _Element_.side_effect = iter(elements_)
-        all_elements = _AllElements(None, None)
+        all_elements = _AllElements(None, None, None)
 
         elements = all_elements._elements
 
@@ -787,7 +787,7 @@ class Describe_AllElements(object):
             {"id": 2, "element": "dict_2"},
             {"id": 6, "element": "dict_6"},
         )
-        all_elements = _AllElements(None, dimension_transforms_dict)
+        all_elements = _AllElements(None, dimension_transforms_dict, None)
 
         element_makings = tuple(all_elements._iter_element_makings())
 
@@ -797,6 +797,53 @@ class Describe_AllElements(object):
             (2, {"id": 6, "element": "dict_6"}, {"element": "xfrms_6"}),
         )
 
+    @pytest.mark.parametrize(
+        "element_transform, dimension_type, element_dict, expected_value",
+        (
+            (
+                {"S2": {"hide": True}, "key": "subvar_id"},
+                DT.NUM_ARRAY,
+                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
+                "S2",
+            ),
+            (
+                {"A1": {"hide": True}, "key": "alias"},
+                DT.NUM_ARRAY,
+                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
+                "A1",
+            ),
+            (
+                {"1": {"hide": True}},
+                DT.CA,
+                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
+                "S2",
+            ),
+            (
+                {"A1": {"hide": True}, "key": "alias"},
+                DT.NUM_ARRAY,
+                {"id": 1, "value": {"references": {"alias": ""}, "id": "S2"}},
+                1,
+            ),
+            (
+                {"A1": {"hide": True}, "key": "alias"},
+                DT.NUM_ARRAY,
+                {"id": 1, "value": {"references": {"alias": None}, "id": "S2"}},
+                1,
+            ),
+            ({"1": {"hide": True}}, DT.CAT, {"id": 1, "name": "Male"}, 1),
+            ({"0001": {"hide": True}}, DT.CAT, {"id": 1, "name": "Male"}, 1),
+        ),
+    )
+    def it_knows_its_element_id_from_dict(
+        self, element_transform, dimension_type, element_dict, expected_value
+    ):
+        dimension_transforms_dict = {"elements": element_transform}
+        all_elements = _AllElements(None, dimension_transforms_dict, dimension_type)
+
+        _element_id_from_dict = all_elements._element_id_from_dict(element_dict)
+
+        assert _element_id_from_dict == expected_value
+
     # fixture components ---------------------------------------------
 
     @pytest.fixture
